import { createRouter, createWebHistory } from "vue-router"
import MasterLayout from "@/layouts/master.vue"

import nprogress from "nprogress";

import { authRouter } from "@/router/auth"
import { plazaRouter } from "@/router/plaza"
import { chatRouter } from "@/router/chat"
import { settingRouter } from "@/router/settings"

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: "/",
      component: MasterLayout,
      children: [
        {
          path: "/u/:alias",
          name: "users.page",
          component: () => import("@/views/users/page.vue")
        },

        {
          path: "/settings",
          component: () => import("@/layouts/settings.vue"),
          children: settingRouter,
        },

        {
          path: "/",
          component: () => import("@/layouts/plaza.vue"),
          children: plazaRouter,
        },

        {
          path: "/chat/:channel",
          component: () => import("@/layouts/chat.vue"),
          children: chatRouter,
        },

        {
          path: "/auth",
          children: authRouter,
        }
      ]
    }
  ]
})

router.beforeEach((_to, _from, next) => {
  nprogress.start()
  next()
})

router.afterEach(() => nprogress.done())

export default router
